# CookieDB Client

The **CookieDB Client** is a client for the [CookieDB Database Server](https://github.com/jaedsonpys/cookiedb-server) where you can create, get, update and delete data in a **remote database**. This project uses class with the same methods as the [CookieDB database](https://github.com/jaedsonpys/cookiedb), so if you want to use it to connect to a CookieDB server, you must learn to use the database first.

- [CookieDB Documentation](https://github.com/jaedsonpys/cookiedb/tree/master/DOCS/database)
- [CookieDB Server](https://github.com/jaedsonpys/cookiedb-server)

See `CookieDBClient` in use in this [simple example](https://github.com/jaedsonpys/cookiedb-client/blob/master/examples/simple_client.py).

## License

```
GNU GENERAL PUBLIC LICENSE
Version 3, 29 June 2007
Copyright © 2023  Jaedson Silva
```

This project uses the `GPL v3.0` license. Please [see the license file](https://github.com/jaedsonpys/cookiedb-client/blob/master/LICENSE) for more informations.